@@ -1,40 +1,32 @@
 # -*- coding: utf-8 -*-
-import sys
-import os
-import locale
-import warnings
-import glob
-import tempfile
-import imp
 import ConfigParser
-import inspect
-import datetime
-import urllib2
-import shutil
-import logging
 from cStringIO import StringIO
-from zipfile import ZipFile
+import datetime
+import glob
+import imp
+import inspect
+import json
+import locale
+import logging
+import os
+import shutil
+import sys
+import tempfile
+import urllib2
+import warnings
 from xml.sax._exceptions import SAXParseException
+from zipfile import ZipFile
+
 import dabo
-import dabo.ui
-import dabo.db
-import dabo.dLocalize as dLocalize
 import dabo.dException as dException
+import dabo.dLocalize as dLocalize
 from dabo.dLocalize import _
 from dabo.lib import connParser
-from dSecurityManager import dSecurityManager
 from dabo.lib.SimpleCrypt import SimpleCrypt
 from dabo.dObject import dObject
+from dabo.dPref import dPref
 from dabo import dUserSettingProvider
-from dabo.lib.RemoteConnector import RemoteConnector
-from dabo.lib.utils import ustr
-from dabo.lib.utils import cleanMenuCaption
-
-try:
-	import simplejson
-except ImportError:
-	# Not installed on the user's Python
-	simplejson = None
+from dSecurityManager import dSecurityManager
 
 
 
@@ -132,8 +124,8 @@ class dApp(dObject):
 	All Dabo objects have an Application property which refers to the dApp
 	instance. Instantiate your dApp object from your main script, like so::
 
-	>>> import dabo
-	>>> app = dabo.dApp
+	>>> from dabo.dApp import dApp
+	>>> app = dApp()
 	>>> app.start()
 
 	Normally, dApp gets instantiated from the client app's main Python script,
@@ -181,9 +173,6 @@ class dApp(dObject):
 		if dabo.loadUserLocale:
 			locale.setlocale(locale.LC_ALL, '')
 
-		# Subdirectories that make up a standard Dabo app
-		self._standardDirs = dabo._getAppDirectoryNames()
-
 		# Some apps, such as the visual tools, are meant to be run from directories
 		# other than that where they are located. In those cases, use the current dir.
 		self._ignoreScriptDir = ignoreScriptDir
@@ -214,7 +203,7 @@ class dApp(dObject):
 		self._tempFileHolder = TempFileHolder()
 		self.getTempFile = self._tempFileHolder.getTempFile
 		# Create the framework-level preference manager
-		self._frameworkPrefs = dabo.dPref(key="dabo_framework")
+		self._frameworkPrefs = dPref(key="dabo_framework")
 		# Hold a reference to the bizobj and connection, if any, controlling
 		# the current database transaction
 		self._transactionTokens = {}
@@ -307,6 +296,8 @@ try again when it is running.
 
 	def setup(self, initUI=True):
 		"""Set up the application object."""
+		if initUI:
+			import dabo.ui
 		# dabo is going to want to import various things from the Home Directory
 		if self.HomeDirectory not in sys.path:
 			sys.path.append(self.HomeDirectory)
@@ -513,17 +504,6 @@ try again when it is running.
 		self._appInfo[item] = value
 
 
-	def _currentUpdateVersion(self):
-		localVers = dabo.version["file_revision"]
-		try:
-			localVers = localVers.split(":")[1]
-		except IndexError:
-			# Not a mixed version
-			pass
-		ret = int("".join([ch for ch in localVers if ch.isdigit()]))
-		return ret
-
-
 	def _resetWebUpdateCheck(self):
 		"""
 		Sets the time that Web Update was last checked to the passed value. Used
@@ -588,13 +568,8 @@ try again when it is running.
 				runCheck = (now > (lastcheck + mins))
 
 		if runCheck:
-			currVers = self._currentUpdateVersion()
 			# See if there is a later version
-			if simplejson:
-				# It's installed
-				url = "%s/check/%s" % (dabo.webupdate_urlbase, currVers)
-			else:
-				url = "%s/checkNoJson/%s" % (dabo.webupdate_urlbase, currVers)
+			url = "%s/check/%s" % (dabo.webupdate_urlbase, dabo.__version__)
 			try:
 				resp = urllib2.urlopen(url).read()
 			except urllib2.URLError, e:
@@ -606,12 +581,7 @@ try again when it is running.
 			except StandardError, e:
 				dabo.log.error(_("Failed to open URL '%(url)s'. Error: %(e)s") % locals())
 				return e
-			if simplejson:
-				resp = simplejson.loads(resp)
-			else:
-				# Sucks using eval(), but that's really the only choice without simplejson
-				# (or rewriting yet again).
-				resp = eval(resp)
+			resp = json.loads(resp)
 		prf.setValue("last_check", now)
 		return (firstTime, resp)
 
@@ -619,9 +589,9 @@ try again when it is running.
 	def _updateFramework(self):
 		"""
 		Get any changed files from the dabodev.com server, and replace
-		the local copies with them."""
-		currVers = self._currentUpdateVersion()
-		fileurl = "%s/files/%s" % (dabo.webupdate_urlbase, currVers)
+		the local copies with them.
+		"""
+		fileurl = "%s/files/%s" % (dabo.webupdate_urlbase, dabo.__version__)
 		try:
 			resp = urllib2.urlopen(fileurl)
 		except StandardError, e:
@@ -966,7 +936,7 @@ try again when it is running.
 		currsyspath = sys.path
 		if not currdir in sys.path:
 			sys.path.insert(0, currdir)
-		for dd in self._standardDirs:
+		for dd in dabo._standardDirs:
 			currmod = getattr(self, dd, None)
 			if currmod:
 				# Module has already been imported; reload to get current state.
@@ -989,7 +959,7 @@ try again when it is running.
 	def getStandardDirectories(self):
 		"""Return a tuple of the fullpath to each standard directory"""
 		hd = self.HomeDirectory
-		subdirs = [os.path.join(hd, dd) for dd in self._standardDirs]
+		subdirs = [os.path.join(hd, dd) for dd in dabo._standardDirs]
 		subdirs.insert(0, hd)
 		return tuple(subdirs)
 
@@ -1104,7 +1074,7 @@ try again when it is running.
 		If a starting file path is provided, use that first. If not, use the
 		HomeDirectory as the starting point.
 		"""
-		stdDirs = self._standardDirs + ("main.py", )
+		stdDirs = dabo._standardDirs + ("main.py", )
 		if dirname not in stdDirs:
 			dabo.log.error(_("Non-standard directory '%s' requested") % dirname)
 			return None
@@ -1404,24 +1374,6 @@ try again when it is running.
 		self._cryptoProvider = SimpleCrypt(key=val)
 
 
-# 	def _getDatabaseActivityLog(self):
-# 		return dabo.dbActivityLog
-#
-# 	def _setDatabaseActivityLog(self, val):
-# 		try:
-# 			dbLogger = dabo.dbActivityLog
-# 			for hnd in dbLogger.handlers:
-# 				dbLogger.removeHandler(hnd)
-# 			dabo.dbLogHandler = logging.handlers.RotatingFileHandler(filename=val,
-# 					maxBytes=dabo.maxLogFileSize, encoding=self.Encoding)
-# 			dbLogger.addHandler(dabo.dbLogHandler)
-# 			dbLogger.setLevel(logging.INFO)
-# 			dabo.dbLogHandler.setLevel(logging.INFO)
-# 		except IOError, e:
-# 			dabo.log.error(_("Could not open file: '%(val)s': %(e)s") % locals())
-# 			return
-
-
 	def _getDefaultMenuBarClass(self):
 		try:
 			cls = self._defaultMenuBarClass
@@ -1488,7 +1440,7 @@ try again when it is running.
 					else:
 						# See if it's a child directory of a standard Dabo app structure
 						dname = os.path.basename(hd)
-						if dname in self._standardDirs:
+						if dname in dabo._standardDirs:
 							hd = os.path.dirname(hd)
 				else:
 					try:
@@ -1613,6 +1565,7 @@ try again when it is running.
 
 
 	def _getRemoteProxy(self):
+		from dabo.lib.RemoteConnector import RemoteConnector
 		if self.SourceURL:
 			try:
 				return self._remoteProxy
@@ -1763,10 +1716,6 @@ try again when it is running.
 			each time this property is set, a new PyCrypto instance is created, and
 			any previous crypto objects are released. Write-only.  (varies)"""))
 
-# 	DatabaseActivityLog = property(_getDatabaseActivityLog, _setDatabaseActivityLog, None,
-# 			_("""Path to the file (or file-like object) to be used for logging all database
-# 			activity. Default=None, which means no log is kept.   (file or str)"""))
-
 	DefaultForm = property(_getDefaultForm, _setDefaultForm, None,
 			_("""The form class to open by default, automatically, after app instantiation.  (form class reference)"""))
 	default_form = DefaultForm  ## backwards-compatibility
@@ -1812,8 +1761,8 @@ try again when it is running.
 			based on the value of MainFormClass. If you want to swap in your own
 			MainForm instance, do it after setup() but before start(), as in::
 
-			>>> import dabo
-			>>> app = dabo.dApp()
+			>>> from dabo.dApp import dApp
+			>>> app = dApp()
 			>>> app.setup()
 			>>> app.MainForm = myMainFormInstance
 			>>> app.start()
@@ -1828,8 +1777,8 @@ try again when it is running.
 			main form, or set to your own main form class. Do this before calling
 			dApp.start(), as in::
 
-			>>> import dabo
-			>>> app = dabo.dApp()
+			>>> from dabo.dApp import dApp
+			>>> app = dApp()
 			>>> app.MainFormClass = MyMainFormClass
 			>>> app.start()
 			
