@@ -487,14 +487,14 @@ class dCursorMixin(dObject):
 		ac._assocPKColOther = self._assocPKColOther
 
 
-	def requery(self, params=None):
+	def requery(self, params=None, convertQMarks=False):
 		currSQL = self.CurrentSQL
 		newQuery = (self._lastSQL != currSQL)
 		self._lastSQL = currSQL
 		self.lastParams = params
 		self._savedStructureDescription = []
 
-		self.execute(currSQL, params)
+		self.execute(currSQL, params, convertQMarks=convertQMarks)
 
 		# clear mementos and new record flags:
 		self._mementos = {}
@@ -1447,10 +1447,11 @@ xsi:noNamespaceSchemaLocation = "http://dabodev.com/schema/dabocursor.xsd">
 				kf = (kf,)
 			for fld in kf:
 				rec[fld] = blank[fld]
-		try:
-			del rec[kons.CURSOR_TMPKEY_FIELD]
-		except KeyError:
-			pass
+		for delfld in (kons.CURSOR_TMPKEY_FIELD, kons.CURSOR_FIELD_TYPES_CORRECTED):
+			try:
+				del rec[delfld]
+			except KeyError:
+				pass
 		self.appendDataSet((rec,))
 
 
@@ -2954,9 +2955,8 @@ xsi:noNamespaceSchemaLocation = "http://dabodev.com/schema/dabocursor.xsd">
 		if self.RowCount <= 0:
 			return False
 		try:
-			getattr(self.Record, kons.CURSOR_TMPKEY_FIELD)
-			return True
-		except dException.FieldNotFoundException:
+			return (kons.CURSOR_TMPKEY_FIELD in self._records[self.RowNumber])
+		except IndexError:
 			return False
 
 
@@ -3089,7 +3089,8 @@ xsi:noNamespaceSchemaLocation = "http://dabodev.com/schema/dabocursor.xsd">
 				| 2: pk field (bool)
 				| 3: table name (str)
 				| 4: field name (str)
-				| 5: field scale (int or None)
+				| 5: field scale for numeric, display size for character
+					type fields (int or None)
 
 				This information will try to come from a few places, in order:
 
