@@ -14,6 +14,7 @@ from dabo.lib.utils import ustr
 class dDataControlMixinBase(dabo.ui.dControlMixin):
 	"""Provide common functionality for the data-aware controls."""
 	def __init__(self, *args, **kwargs):
+		self._deriveTextLengthFromSource = dabo.dTextBox_DeriveTextLengthFromSource
 		self._disableOnEmptyDataSource = dabo.autoDisableDataControls
 		self._fldValidFailed = False
 		# Control enabling/disabling on empty data source helper attribute.
@@ -125,7 +126,7 @@ class dDataControlMixinBase(dabo.ui.dControlMixin):
 
 	def __dataUpdate(self):
 		"""This handles all the value updating from the data source."""
-		if not self.DataField or not (self.DataSource or isinstance(self.DataSource, dabo.dPref)):
+		if not self.DataField or not (self.DataSource or isinstance(self.DataSource, dPref)):
 			return
 		if self._DesignerMode:
 			return
@@ -256,7 +257,7 @@ class dDataControlMixinBase(dabo.ui.dControlMixin):
 			# To prevent such situation we have to check the _from_flushValue attribute at the beginning.
 			self._from_flushValue = True
 			if not self._DesignerMode:
-				if (self.DataSource or isinstance(self.DataSource, dabo.dPref)) and self.DataField:
+				if (self.DataSource or isinstance(self.DataSource, dPref)) and self.DataField:
 					src = self.Source
 					if self._srcIsBizobj:
 						try:
@@ -305,8 +306,8 @@ class dDataControlMixinBase(dabo.ui.dControlMixin):
 			# Raise an event so that user code can react if needed:
 			if self._userChanged:
 				self._userChanged = False
-				self.raiseEvent(dabo.dEvents.InteractiveChange, oldVal=oldVal)
-			dabo.ui.callAfterInterval(200, self.raiseEvent, dabo.dEvents.ValueChanged)
+				self.raiseEvent(dEvents.InteractiveChange, oldVal=oldVal)
+			self.raiseEvent(dEvents.ValueChanged)
 		return ret
 
 
@@ -478,7 +479,7 @@ class dDataControlMixinBase(dabo.ui.dControlMixin):
 		if self.__src is None:
 			ds = self.DataSource
 			self._srcIsBizobj = False
-			if (ds or isinstance(ds, dabo.dPref)):
+			if (ds or isinstance(ds, dPref)):
 				# First, see if it's a string
 				if isinstance(ds, basestring):
 					# Source can be a bizobj, which we get from the form, or
@@ -537,6 +538,14 @@ class dDataControlMixinBase(dabo.ui.dControlMixin):
 				# It's tricky, because object attribute/property takes precedence before data field of the same name.
 				if self._srcIsBizobj:
 					self._srcIsBizobj = not hasattr(self.__src, self.DataField)
+			if self._srcIsBizobj and self._deriveTextLengthFromSource and \
+					hasattr(self, "TextLength"):
+				field = self.DataField
+				for descr in self.__src.DataStructure:
+					if descr[0] == field:
+						if descr[1] == "C":
+							self.TextLength = descr[5]
+						break
 		return self.__src
 
 
