@@ -101,6 +101,7 @@ from dCalendar import dCalendar
 from dCalendar import dExtendedCalendar
 from dCheckBox import dCheckBox
 from dCheckList import dCheckList
+from dCollapsiblePanel import dCollapsiblePanel
 from dColorDialog import dColorDialog
 from dComboBox import dComboBox
 from dDatePicker import dDatePicker
@@ -184,6 +185,7 @@ from dTimer import dTimer
 from dToolBar import dToolBar
 from dToolBar import dToolBarItem
 from dToggleButton import dToggleButton
+from dTreeView import dNode
 from dTreeView import dTreeView
 from dLed import dLed
 import dUICursors as dUICursors
@@ -1218,8 +1220,7 @@ def getSystemInfo(returnType=None):
 	else:
 		appVersion = "?"
 		appName = "Dabo"
-	ds.append({"name": "Dabo Version:", "value": "Version %s; Revision %s"
-			% (dabo.version["version"], dabo.version["revision"])})
+	ds.append({"name": "Dabo Version:", "value": dabo.__version__})
 	ds.append({"name": "UI Version:", "value": "%s on %s" % (dabo.ui.uiType["version"],
 			dabo.ui.uiType["platform"])})
 	if rType == "d":
@@ -1455,7 +1456,7 @@ def makeGridEditor(controlClass, minWidth=None, minHeight=None, **controlProps):
 				raise TypeError(_("Cannot create custom editor without a control class specified."))
 			self._control = self._controlClass(parent, **controlProps)
 			self._grid = parent.GetParent()
-			self._control.bindEvent(dabo.dEvents.KeyDown, self._onKeyDown)
+			self._control.bindEvent(dEvents.KeyDown, self._onKeyDown)
 			self.SetControl(self._control)
 			if evtHandler:
 				self._control.PushEventHandler(evtHandler)
