@@ -6,6 +6,7 @@ import logging
 import wx
 import dabo
 import dabo.ui as ui
+import dabo.dColors as dColors
 import dabo.dEvents as dEvents
 import dabo.lib.utils as utils
 from dabo.dObject import dObject
@@ -45,7 +46,7 @@ class SplashScreen(wx.Frame):
 
 		if maskColor is not None:
 			if isinstance(maskColor, basestring):
-				maskColor = dabo.dColors.colorTupleFromName(maskColor)
+				maskColor = dColors.colorTupleFromName(maskColor)
 			self._bmp.SetMask(wx.Mask(self._bmp, maskColor))
 
 		if wx.Platform == "__WXGTK__":
@@ -155,7 +156,8 @@ class uiApp(dObject, wx.App):
 		self._mruMenuFuncs = {}
 		self._mruMenuLinks = {}
 		self._mruMaxItems = 12
-		wx.InitAllImageHandlers()
+		if wx.VERSION < (2, 9):  ## Done automatically now 
+			wx.InitAllImageHandlers()
 		# Set up the debug logging
 		self.debugWindow = None
 		# Set up the object inspector
@@ -202,7 +204,6 @@ class uiApp(dObject, wx.App):
 		if self.callback is not None:
 			wx.CallAfter(self.callback)
 		del self.callback
-		self.Bind(wx.EVT_KEY_DOWN, self._onKeyPress)
 		return True
 
 
@@ -313,7 +314,7 @@ these automatic updates.""").replace("\n", " ")
 							title=_("No Update Needed"))
 					answer = False
 				else:
-					dabo.ui.info(_("Dabo has been updated to the current revision. The app "
+					dabo.ui.info(_("Dabo has been updated to the current master version. The app "
 							"will now exit. Please re-run the application."), title=_("Success!"))
 		return not answer
 
@@ -375,7 +376,7 @@ these automatic updates.""").replace("\n", " ")
 		return ret
 
 
-	def _onKeyPress(self, evt):
+	def _handleZoomKeyPress(self, evt):
 		## Zoom In / Out / Normal:
 		alt = evt.AltDown()
 		ctl = evt.ControlDown()
@@ -400,7 +401,8 @@ these automatic updates.""").replace("\n", " ")
 		elif slash:
 			self.fontZoomNormal()
 		else:
-			evt.Skip()
+			return False
+		return True
 
 
 	# The following three functions handle font zooming
@@ -500,17 +502,16 @@ these automatic updates.""").replace("\n", " ")
 
 	def _onWxKeyChar(self, evt):
 		self.dApp.raiseEvent(dEvents.KeyChar, evt)
-		evt.Skip()
 
 
 	def _onWxKeyDown(self, evt):
+		if self._handleZoomKeyPress(evt):
+			return 
 		self.dApp.raiseEvent(dEvents.KeyDown, evt)
-		evt.Skip()
 
 
 	def _onWxKeyUp(self, evt):
 		self.dApp.raiseEvent(dEvents.KeyUp, evt)
-		evt.Skip()
 
 
 	def onCmdWin(self, evt):
